@@ -217,7 +217,7 @@ use std::{
 };
 
 use csv_index::RandomAccessSimple;
-#[cfg(any(feature = "full", feature = "lite"))]
+#[cfg(any(feature = "feature_capable", feature = "lite"))]
 use indicatif::{ProgressBar, ProgressDrawTarget, ProgressStyle};
 use log::{debug, info, log_enabled};
 use mlua::{Lua, LuaSerdeExt, Value};
@@ -650,12 +650,12 @@ fn sequential_mode(
     #[cfg(feature = "datapusher_plus")]
     let show_progress = false;
 
-    #[cfg(any(feature = "full", feature = "lite"))]
+    #[cfg(any(feature = "feature_capable", feature = "lite"))]
     let show_progress =
         (args.flag_progressbar || std::env::var("QSV_PROGRESSBAR").is_ok()) && !rconfig.is_stdin();
-    #[cfg(any(feature = "full", feature = "lite"))]
+    #[cfg(any(feature = "feature_capable", feature = "lite"))]
     let progress = ProgressBar::with_draw_target(None, ProgressDrawTarget::stderr_with_hz(5));
-    #[cfg(any(feature = "full", feature = "lite"))]
+    #[cfg(any(feature = "feature_capable", feature = "lite"))]
     if show_progress {
         util::prep_progress(&progress, util::count_rows(rconfig)?);
     } else {
@@ -673,7 +673,7 @@ fn sequential_mode(
     // main loop
     // without an index, we stream the CSV in sequential order
     'main: while rdr.read_record(&mut record)? {
-        #[cfg(any(feature = "full", feature = "lite"))]
+        #[cfg(any(feature = "feature_capable", feature = "lite"))]
         if show_progress {
             progress.inc(1);
         }
@@ -835,7 +835,7 @@ fn sequential_mode(
     }
 
     wtr.flush()?;
-    #[cfg(any(feature = "full", feature = "lite"))]
+    #[cfg(any(feature = "feature_capable", feature = "lite"))]
     if show_progress {
         util::finish_progress(&progress);
     }
@@ -980,12 +980,12 @@ fn random_acess_mode(
     #[cfg(feature = "datapusher_plus")]
     let show_progress = false;
 
-    #[cfg(any(feature = "full", feature = "lite"))]
+    #[cfg(any(feature = "feature_capable", feature = "lite"))]
     let show_progress =
         (args.flag_progressbar || std::env::var("QSV_PROGRESSBAR").is_ok()) && !rconfig.is_stdin();
-    #[cfg(any(feature = "full", feature = "lite"))]
+    #[cfg(any(feature = "feature_capable", feature = "lite"))]
     let progress = ProgressBar::with_draw_target(None, ProgressDrawTarget::stderr_with_hz(5));
-    #[cfg(any(feature = "full", feature = "lite"))]
+    #[cfg(any(feature = "feature_capable", feature = "lite"))]
     if show_progress {
         progress.set_style(
             ProgressStyle::default_bar()
@@ -1013,7 +1013,7 @@ fn random_acess_mode(
     'main: while idx_file.read_record(&mut record)? {
         globals.set("_IDX", curr_record)?;
 
-        #[cfg(any(feature = "full", feature = "lite"))]
+        #[cfg(any(feature = "feature_capable", feature = "lite"))]
         if show_progress {
             progress.set_position(curr_record + 1);
         }
@@ -1175,7 +1175,7 @@ fn random_acess_mode(
 
     wtr.flush()?;
     let msg = format!("RANDOM ACCESS MODE: Processed {processed_count} record/s.");
-    #[cfg(any(feature = "full", feature = "lite"))]
+    #[cfg(any(feature = "feature_capable", feature = "lite"))]
     if show_progress {
         progress.abandon_with_message(msg.clone());
     }
@@ -1605,6 +1605,95 @@ fn setup_helpers(
     })?;
     luau.globals().set("qsv_fileexists", qsv_fileexists)?;
 
+    // this is a helper function to load a CSV into a Luau table.
+    //
+    //   qsv_loadcsv(table_name: string, filepath: string, key_column: string)
+    //      table_name: the name of the Luau table to load the CSV data into.
+    //        filepath: the path of the CSV file to load
+    //      key_column: the name of the column to use as the key for the table.
+    //                  If the column name is empty, the row number will be used as the key.
+    //         returns: Luau table of column/header names.
+    //                  A Luau runtime error if the filepath is invalid.
+    //
+    let qsv_loadcsv = luau.create_function(
+        move |luau, (table_name, filepath, key_column): (String, String, String)| {
+            if filepath.is_empty() {
+                return helper_err!("qsv_loadcsv", "filepath cannot be empty.");
+            }
+
+            let path = Path::new(&filepath);
+            if !path.exists() {
+                return helper_err!("qsv_loadcsv", "\"{}\" does not exist.", path.display());
+            }
+
+            let csv_table = luau.create_table()?;
+            #[allow(unused_assignments)]
+            let mut record = csv::StringRecord::new();
+
+            let conf = Config::new(&Some(filepath.clone()))
+                .delimiter(delimiter)
+                .comment(Some(b'#'))
+                .no_headers(false);
+
+            let mut rdr = conf.reader()?;
+
+            let headers = match rdr.headers() {
+                Ok(headers) => headers.clone(),
+                Err(e) => {
+                    return helper_err!("qsv_loadcsv", "Cannot read headers of CSV: {e}");
+                }
+            };
+
+            let key_idx = if key_column.is_empty() {
+                // if the key column is empty, set key_idx to a sentinel value
+                // that will never match a valid column index, indicating that
+                // we should use the row number as the key.
+                usize::MAX
+            } else {
+                match headers.iter().position(|x| x == key_column) {
+                    Some(idx) => idx,
+                    None => {
+                        return helper_err!(
+                            "qsv_loadcsv",
+                            "Cannot find key column \"{key_column}\" in CSV."
+                        );
+                    }
+                }
+            };
+
+            for (row_idx, result) in rdr.records().enumerate() {
+                record = result.unwrap_or_default();
+
+                let key = if key_idx == usize::MAX {
+                    let mut buffer = itoa::Buffer::new();
+                    buffer.format(row_idx).to_owned()
+                } else {
+                    record.get(key_idx).unwrap_or_default().trim().to_string()
+                };
+                let inside_table = luau.create_table()?;
+                for (i, header) in headers.iter().enumerate() {
+                    let val = record.get(i).unwrap_or_default().trim();
+                    inside_table.raw_set(header, val)?;
+                }
+                csv_table.raw_set(key, inside_table)?;
+            }
+
+            luau.globals().raw_set(table_name, csv_table)?;
+
+            // now that we've successfully loaded the CSV, we return the headers
+            // as a table so the user can use them to access the values
+            let headers_table = luau.create_table()?;
+            for (i, header) in headers.iter().enumerate() {
+                headers_table.raw_set(i, header)?;
+            }
+
+            info!("{filepath} successfully loaded CSV.");
+
+            Ok(headers_table)
+        },
+    )?;
+    luau.globals().set("qsv_loadcsv", qsv_loadcsv)?;
+
     // this is a helper function that can be called from the BEGIN, MAIN & END scripts to write to
     // a file. The file will be created if it does not exist. The file will be appended to if it
     // already exists. The filename will be sanitized and will be written to the current working
