@@ -1,5 +1,26 @@
 use crate::workdir::Workdir;
 
+#[test]
+fn test_input_comment() {
+    let wrk = Workdir::new("input_comment");
+
+    let test_file = wrk.load_test_file("inputcommenttest.csv");
+
+    let mut cmd = wrk.command("input");
+    cmd.arg("--comment").arg("#").arg(test_file);
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["column1", "column2", "column3"],
+        svec!["a", "1", "alpha"],
+        svec!["b", "2", "beta"],
+        svec!["c", "3", "gamma"],
+        svec!["d", "4", "delta"],
+        svec!["e", "5", "epsilon"],
+    ];
+    assert_eq!(got, expected);
+}
+
 #[test]
 fn test_input_skiplines() {
     let wrk = Workdir::new("input_skiplines");
